﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Services;
using Newtonsoft.Json;
using Cmdjy.Dal;
using Cmdjy.Dal.Wappers;
using System.Data.Entity;

namespace Cmdjy.ws
{
    /// <summary>
    /// HisInterface 的摘要说明
    /// </summary>
    [WebService(Namespace = "http://djy.wondersgroup.com/")]
    [WebServiceBinding(ConformsTo = WsiProfiles.BasicProfile1_1)]
    [System.ComponentModel.ToolboxItem(false)]
    // 若要允许使用 ASP.NET AJAX 从脚本中调用此 Web 服务，请取消注释以下行。 
    // [System.Web.Script.Services.ScriptService]
    public class HisInterface:System.Web.Services.WebService
    {

        [WebMethod(Description = "医疗机构上传处方信息")]
        public string PostPrescriptionInfo(HisPrescriptionInfo info) {
            HisPrescriptionResult result = null;
            using(var db = DbContextFactory.CreateDbContext()) {
                var en = new HisPrescriptyInfoWapper(info) as Dal.Tables.HisPrescriptionInfo;
                en.RawAddress = this.Context.Request.UserHostAddress;
                en.CreateDatetime = DateTime.Now;
                db.Entry(en).State = EntityState.Added;
                try {
                    db.SaveChanges();
                    result = new HisPrescriptionResult {
                        Code = ResultCode.Success,PrescriptionId = en.Id.ToString(),
                        Msg = "保存成功",
                    };
                }
                catch(Exception ex) {
                    result = new HisPrescriptionResult {
                        Code = ResultCode.Exception,PrescriptionId = "0",
                        Msg = ex.ToString(),
                    };
                }
            }
            return JsonConvert.SerializeObject(result);
        }

        [WebMethod(Description = "医疗机构上传药品信息")]
        public string PostDrugInfo(HisDrugInfo info) {
            HisDrugResult result = null;
            using(var db = DbContextFactory.CreateDbContext()) {
                var en = new HisDrugInfoWapper(info) as Dal.Tables.HisDrugInfo;
                en.RawAddress = this.Context.Request.UserHostAddress;
                en.CreateDatetime = DateTime.Now;
                db.Entry(en).State = EntityState.Added;
                try {
                    db.SaveChanges();
                    result = new HisDrugResult {
                        Code = ResultCode.Success,DrugId = en.Id.ToString(),
                        Msg = "保存成功",
                    };
                }
                catch(Exception ex) {
                    result = new HisDrugResult {
                        Code = ResultCode.Exception,DrugId = "0",
                        Msg = ex.ToString(),
                    };
                }
            }
            return JsonConvert.SerializeObject(result);
        }
    }

    /// <summary>
    /// HIS发送的处方信息
    /// </summary>
    public class HisPrescriptionInfo
    {
        /// <summary>
        /// 处方类型
        /// </summary>
        public PrescriptionType Type { get; set; }
        /// <summary>
        /// 如果为退方，这里传要退的处方流水号。此编号在下单应答消息中提供
        /// </summary>
        public string RawRecordId { get; set; }
        /// <summary>
        /// 药品明细数量
        /// </summary>
        public string DrugCount { get; set; }
        /// <summary>
        /// 处方备注
        /// </summary>
        public string Remark { get; set; }
        /// <summary>
        /// 带回病房 否
        /// </summary>
        public string TakeBack { get; set; }
        /// <summary>
        /// "操作类型": "煎药自取", or "操作类型": "煎药快递", or "操作类型": "配药快递"
        /// </summary>
        public string OpType { get; set; }
        /// <summary>
        /// 操作员
        /// </summary>
        public string OpUser { get; set; }
        /// <summary>
        /// 病区
        /// </summary>
        public string Area { get; set; }
        /// <summary>
        /// 病床号
        /// </summary>
        public string Bed { get; set; }
        /// <summary>
        /// 操作时间
        /// </summary>
        public string OpDatatime { get; set; }
        /// <summary>
        /// 处方号
        /// </summary>
        public string PrescriptionNo { get; set; }
        /// <summary>
        /// 处方日期
        /// </summary>
        public string PrescriptionDatatime { get; set; }
        /// <summary>
        /// 单位编号 医疗机构编号
        /// </summary>
        public string HosNo { get; set; }
        /// <summary>
        /// 医疗机构名称
        /// </summary>
        public string HosName { get; set; }
        /// <summary>
        /// 发票号
        /// </summary>
        public string InvoiceNo { get; set; }
        /// <summary>
        /// 病人编号
        /// </summary>
        public string PatientNo { get; set; }
        /// <summary>
        /// 病人卡号
        /// </summary>
        public string CardNo { get; set; }
        /// <summary>
        /// 科室名称
        /// </summary>
        public string DepName { get; set; }
        /// <summary>
        /// 病人年龄
        /// </summary>
        public string PatientAge { get; set; }
        /// <summary>
        /// 病人生日
        /// </summary>
        public string PatientBrithday { get; set; }
        /// <summary>
        /// 病人手机号码
        /// </summary>
        public string PatientMobile { get; set; }
        /// <summary>
        /// 病人电话
        /// </summary>
        public string PatientPhone { get; set; }
        /// <summary>
        /// 所在区县街道
        /// </summary>
        public string District { get; set; }
        /// <summary>
        /// 送货地址
        /// </summary>
        public string PostAddress { get; set; }
        /// <summary>
        /// 送货时间
        /// </summary>
        public string PostDatatime { get; set; }
        /// <summary>
        /// 贴数
        /// </summary>
        public string UseCount { get; set; }
        /// <summary>
        /// 病人性别
        /// </summary>
        public string PatientSex { get; set; }
        /// <summary>
        /// 病人姓名
        /// </summary>
        public string PatientName { get; set; }
        /// <summary>
        /// 医生姓名
        /// </summary>
        public string DoctorName { get; set; }
        /// <summary>
        /// 诊断
        /// </summary>
        public string Diagnosis { get; set; }
        /// <summary>
        /// 用法
        /// </summary>
        public string Usage { get; set; }
        /// <summary>
        /// 治疗号
        /// </summary>
        public string Zlh { get; set; }
        /// <summary>
        /// 收费序号
        /// </summary>
        public int Sfxh { get; set; }
        /// <summary>
        /// 收费费用序号
        /// </summary>
        public string Sffyxh { get; set; }
        /// <summary>
        /// 代煎药厂商代码
        /// </summary>
        public string CompanyCode { get; set; }
        /// <summary>
        /// 代煎药厂商名称
        /// </summary>
        public string CompanyName { get; set; }
    }
    /// <summary>
    /// HIS发送处方信息应答
    /// </summary>
    public class HisPrescriptionResult
    {
        /// <summary>
        /// 返回结果代码
        /// </summary>
        public ResultCode Code { get; set; }
        /// <summary>
        /// 返回信息。如执行错误包含错误信息
        /// </summary>
        public string Msg { get; set; }
        /// <summary>
        /// 处方流水号，执行错误为空
        /// </summary>
        public string PrescriptionId { get; set; }
    }
    /// <summary>
    /// HIS发送的药品信息
    /// </summary>
    public class HisDrugInfo
    {
        /// <summary>
        /// 处方流水号
        /// </summary>
        public string PrescriptionId { get; set; }
        /// <summary>
        /// "药品医保代码":"YP0306401000650",
        /// </summary>
        public string DrugNo { get; set; }
        /// <summary>
        /// 药品单价 0.085
        /// </summary>
        public string Price { get; set; }
        /// <summary>
        /// 单贴数量
        /// </summary>
        public string Count { get; set; }
        /// <summary>
        /// 单位 克
        /// </summary>
        public string Unit { get; set; }
        /// <summary>
        /// 单项总价
        /// </summary>
        public string Sum { get; set; }
        /// <summary>
        /// 规格  15.00000000
        /// </summary>
        public string DrugType { get; set; }
        /// <summary>
        /// 药品编码
        /// </summary>
        public string DrugLocalNo { get; set; }
        /// <summary>
        /// 药品名称
        /// </summary>
        public string DrugName { get; set; }
        /// <summary>
        /// 特殊要求
        /// </summary>
        public string Remark { get; set; }
    }
    /// <summary>
    /// HIS发送的药品信息应答
    /// </summary>
    public class HisDrugResult
    {
        /// <summary>
        /// 返回结果代码
        /// </summary>
        public ResultCode Code { get; set; }
        /// <summary>
        /// 返回信息。如执行错误包含错误信息
        /// </summary>
        public string Msg { get; set; }
        /// <summary>
        /// 药品流水号，执行错误为空
        /// </summary>
        public string DrugId { get; set; }
    }
    /// <summary>
    /// 处方类型
    /// </summary>
    [Flags]
    public enum PrescriptionType
    {
        /// <summary>
        /// 订单
        /// </summary>
        Order = 1,
        /// <summary>
        /// 撤销订单，退单
        /// </summary>
        CancelOrder = 2,
        /// <summary>
        /// 测试方。测试处方不会发送给第三方
        /// </summary>
        TestOrder = 4,
    }

    /// <summary>
    /// 接口执行结果
    /// </summary>
    [Flags]
    public enum ResultCode
    {
        /// <summary>
        /// 执行成功。
        /// </summary>
        Success = 1,
        /// <summary>
        /// 发生异常
        /// </summary>
        Exception = 2,
    }
}
